Learn R Programming

metarep (version 1.2.1)

summary.metarep: Summary of meta-analysis with replicability-analysis results

Description

Summary method for objects of class 'metarep'.

Usage

# S3 method for metarep
summary(object, ...)

Value

A list of the quantities for replicability analysis, as follows:

meta-analysis results:

Summary of the supplied 'meta' object.

r.value:

r-value of the tested alternative.

u.increased:

Maximal number of studies at which replicability of increasing effect can be claimed. It will be reported unless the alternative is 'less'.

u.decreased:

Maximal number of studies at which replicability of increasing effect can be claimed. It will be reported unless the alternative is 'greater'.

Arguments

object

An object of class 'metarep'.

...

Arguments to be passed to methods, see summary.meta

Examples

Run this code
n.i.1 <- c( 20, 208, 24, 190, 58, 36, 51)
a.i <- c( 2,79,0,98,15,34,9) 
n.i.2 <- c( 20, 119, 22, 185, 29, 51, 47)
c.i <- c(9,106,14,98,12,49,9) 
m1 <- metabin( event.e = a.i,n.e = n.i.1,event.c = c.i,n.c = n.i.2,
               studlab = paste0('Study ' , 1:7) , sm = 'OR' ,
               common = FALSE, random = TRUE )
mr1 <- metarep(  m1 , u = 2, common.effect = FALSE , t = 0.05 , 
               alternative = 'two-sided', report.u.max = TRUE)
               summary(mr1)

Run the code above in your browser using DataLab